@@ -1,7 +1,7 @@
 /*
- * DB-ALLe - Archive for punctual meteorological data
+ * wreport/aliases - Aliases for commonly used variable codes
  *
- * Copyright (C) 2005,2006  ARPA-SIM <urpsim@smr.arpa.emr.it>
+ * Copyright (C) 2005--2010  ARPA-SIM <urpsim@smr.arpa.emr.it>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,20 +19,17 @@
  * Author: Enrico Zini <enrico@enricozini.com>
  */
 
-#ifndef DBALLE_CORE_ALIASES_H
-#define DBALLE_CORE_ALIASES_H
-
-#ifdef  __cplusplus
-extern "C" {
-#endif
+#ifndef WREPORT_CORE_ALIASES_H
+#define WREPORT_CORE_ALIASES_H
 
 /** @file
  * @ingroup core
  * Resolve aliases to variable codes
  */
 
-#include <dballe/core/var.h>
+#include <wreport/varinfo.h>
 
+namespace dballe {
 
 /**
  * Resolve a variable alias.
@@ -43,7 +40,7 @@ extern "C" {
  *   The varcode corresponding to the aliase, or 0 if no variable has the given
  *   alias.  See @ref vartable.h
  */
-dba_varcode dba_varcode_alias_resolve(const char* alias);
+wreport::Varcode varcode_alias_resolve(const char* alias);
 
 /**
  * Resolve a variable alias.
@@ -56,11 +53,16 @@ dba_varcode dba_varcode_alias_resolve(const char* alias);
  *   The varcode corresponding to the aliase, or 0 if no variable has the given
  *   alias.  See @ref vartable.h
  */
-dba_varcode dba_varcode_alias_resolve_substring(const char* alias, int len);
+wreport::Varcode varcode_alias_resolve_substring(const char* alias, int len);
+
+/**
+ * Look for the aliase for a Varcode.
+ *
+ * @returns The alias string, or NULL if the varcode has no alias
+ */
+const char* varcode_alias_resolve_reverse(wreport::Varcode code);
 
-#ifdef  __cplusplus
 }
-#endif
 
 /* vim:set ts=4 sw=4: */
 #endif
